@@ -24,6 +24,7 @@ from twisted.cred import checkers, portal
 from zope.interface import implements
 
 from buildslave import bot
+from buildslave.test.util import misc
 
 from mock import Mock
 
@@ -61,7 +62,7 @@ class MasterRealm:
     def shutdown(self):
         return self.mind.broker.transport.loseConnection()
 
-class TestBuildSlave(unittest.TestCase):
+class TestBuildSlave(misc.PatcherMixin, unittest.TestCase):
 
     def setUp(self):
         self.realm = None
@@ -73,10 +74,6 @@ class TestBuildSlave(unittest.TestCase):
             shutil.rmtree(self.basedir)
         os.makedirs(self.basedir)
 
-        # the slave tries to call socket.getfqdn to write its hostname; this hangs
-        # without network, so fake it
-        self.patch(socket, "getfqdn", lambda : 'test-hostname.domain.com')
-
     def tearDown(self):
         d = defer.succeed(None)
         if self.realm:
@@ -98,24 +95,20 @@ class TestBuildSlave(unittest.TestCase):
         # return the dynamically allocated port number
         return self.listeningport.getHost().port
 
-    def test_keepalive_called(self):
-        # set up to fire this deferred on receipt of a keepalive
-        d = defer.Deferred()
-        def on_keepalive():
-            # need to wait long enough for the remote_keepalive call to
-            # finish, but not for another one to queue up
-            reactor.callLater(0.01, d.callback, None)
-        persp = MasterPerspective(on_keepalive=on_keepalive)
+    def test_constructor_minimal(self):
+        # only required arguments
+        bot.BuildSlave('mstr', 9010, 'me', 'pwd', '/s', 10, False)
 
-        # start up the master and slave, with a very short keepalive
-        port = self.start_master(persp)
-        self.buildslave = bot.BuildSlave("127.0.0.1", port,
-                "testy", "westy", self.basedir,
-                keepalive=0.1, keepaliveTimeout=0.05, usePTY=False)
-        self.buildslave.startService()
+    def test_constructor_083_tac(self):
+        # invocation as made from default 083 tac files
+        bot.BuildSlave('mstr', 9010, 'me', 'pwd', '/s', 10, False,
+                umask=0123, maxdelay=10)
 
-        # and wait for it to keepalive
-        return d
+    def test_constructor_full(self):
+        # invocation with all args
+        bot.BuildSlave('mstr', 9010, 'me', 'pwd', '/s', 10, False,
+                umask=0123, maxdelay=10, keepaliveTimeout=10,
+                unicode_encoding='utf8', allow_shutdown=True)
 
     def test_buildslave_print(self):
         d = defer.Deferred()
@@ -126,7 +119,7 @@ class TestBuildSlave(unittest.TestCase):
             print_d = mind.callRemote("print", "Hi, slave.")
             print_d.addCallbacks(d.callback, d.errback)
 
-        # start up the master and slave, with a very short keepalive
+        # start up the master and slave
         persp = MasterPerspective()
         port = self.start_master(persp, on_attachment=call_print)
         self.buildslave = bot.BuildSlave("127.0.0.1", port,
@@ -137,10 +130,26 @@ class TestBuildSlave(unittest.TestCase):
         # and wait for the result of the print
         return d
 
-    def test_hostname_file(self):
+    def test_recordHostname_uname(self):
+        self.patch_os_uname(lambda : [ 0, 'test-hostname.domain.com' ])
+
         self.buildslave = bot.BuildSlave("127.0.0.1", 9999,
                 "testy", "westy", self.basedir,
                 keepalive=0, usePTY=False, umask=022)
+        self.buildslave.recordHostname(self.basedir)
+        self.assertEqual(open(os.path.join(self.basedir, "twistd.hostname")).read().strip(),
+                         'test-hostname.domain.com')
+
+    def test_recordHostname_getfqdn(self):
+        def missing():
+            raise AttributeError
+        self.patch_os_uname(missing)
+        self.patch(socket, "getfqdn", lambda : 'test-hostname.domain.com')
+
+        self.buildslave = bot.BuildSlave("127.0.0.1", 9999,
+                "testy", "westy", self.basedir,
+                keepalive=0, usePTY=False, umask=022)
+        self.buildslave.recordHostname(self.basedir)
         self.assertEqual(open(os.path.join(self.basedir, "twistd.hostname")).read().strip(),
                          'test-hostname.domain.com')
 
